@@ -73,7 +73,7 @@ def quote(text):
   'Handle quote characters'
 
   # Convert to unicode.
-  if type(text) != unicode:
+  if not isinstance(text, unicode):
     text = text.decode('utf-8')
 
   # Look for quote characters. Keep the text as is if it's already quoted.
@@ -94,7 +94,7 @@ def checkdata(data):
     # Column names
     if key in [None, '']:
       raise ValueError('key must not be blank')
-    elif type(key) not in (unicode, str):
+    elif not isinstance(key, (unicode, str)):
       raise ValueError(u'The column name must be of unicode or str type. The column name ("%s") is of type %s. If this error doesn\'t make sense, try "unicode(\'%s\')".' % (key, type(key), key))
-    elif type(value) == dict and not set(map(type, value.keys())).issubset({unicode, str}):
+    elif isinstance(value, dict) and not all(isinstance(k, (unicode, str)) for k in value.keys()):
       raise ValueError('Dictionary keys must all be str or unicode for database insert.')
